**To delete a packaging group**

The following ``delete-packaging-group`` example deletes the packaging group named ``Dash_widevine``. ::

    aws mediapackage-vod delete-packaging-group \
        --id Dash_widevine

This command produces no output.

For more information, see `Deleting a Packaging Group <https://docs.aws.amazon.com/mediapackage/latest/ug/pkg-group-delete.html>`__ in the *AWS Elemental MediaPackage User Guide*.
